@@ -1,5 +1,5 @@
-from superset.db_engines.ssas.db import connect
-from superset.db_engines.ssas.exceptions import (
+from .db import connect
+from .exceptions import (
     DataError,
     DatabaseError,
     Error,
