@@ -14,7 +14,7 @@ from sqlalchemy import create_engine
 import pandas as pd
 import requests
 
-from superset.db_engines.ssas.exceptions import Error, NotSupportedError, ProgrammingError
+from .exceptions import Error, NotSupportedError, ProgrammingError
 from olap.xmla.xmla import XMLAProvider
 
 from requests.auth import HTTPBasicAuth
